"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkEntityFieldMetadata = void 0;
const param_case_1 = require("param-case");
function checkEntityFieldMetadata(name, queryParams, entityMetadata, sourceParameter) {
    let primaryColumns = entityMetadata.primaryColumns.map((prop) => prop.propertyPath);
    const relations = entityMetadata.relations.map((prop) => prop.propertyPath);
    let columns = entityMetadata.columns.map((prop) => prop.propertyPath);
    const errors = [];
    if (name.split('.').length === 1) {
        if (![...columns, ...primaryColumns, ...relations].find((i) => i === name)) {
            errors.push({
                detail: `Field '${name.toLocaleLowerCase()}' does not exist`,
                source: {
                    parameter: sourceParameter,
                },
            });
        }
        if (queryParams["include" /* include */] && Array.isArray(queryParams["include" /* include */])) {
            if (relations.includes(name) && !queryParams["include" /* include */].includes(name)) {
                errors.push({
                    detail: `Add '${name}' to query param 'include'`,
                    source: {
                        parameter: sourceParameter,
                    },
                });
            }
        }
        return errors;
    }
    if (name.split('.').length > 2) {
        errors.push({
            detail: `Field '${name.toLocaleLowerCase()}' incorrect format`,
            source: {
                parameter: sourceParameter,
            },
        });
        return errors;
    }
    const [relation, column] = name.split('.');
    if (param_case_1.paramCase(entityMetadata.name) === relation) {
        const nestedErrors = checkEntityFieldMetadata(column, queryParams, entityMetadata, sourceParameter);
        errors.push(...nestedErrors);
        return errors;
    }
    if (!entityMetadata.relations.find(item => item.propertyPath === relation)) {
        errors.push({
            detail: `Relation '${param_case_1.paramCase(relation)}' does not exist`,
            source: {
                parameter: sourceParameter,
            },
        });
        return errors;
    }
    if (queryParams["include" /* include */] && Array.isArray(queryParams["include" /* include */])) {
        if (!queryParams["include" /* include */].find(item => item === relation)) {
            errors.push({
                detail: `Add '${param_case_1.paramCase(relation)}' to query param 'include'`,
                source: {
                    parameter: sourceParameter,
                },
            });
            return errors;
        }
    }
    const relationMetadata = entityMetadata.relations.find(item => item.propertyPath === relation);
    primaryColumns = relationMetadata.inverseEntityMetadata.primaryColumns.map((prop) => prop.propertyPath);
    columns = relationMetadata.inverseEntityMetadata.columns.map((prop) => prop.propertyPath);
    if (![...columns, ...primaryColumns].find((i) => i === column)) {
        errors.push({
            detail: `Relation: '${param_case_1.paramCase(relation)}' in resource '${param_case_1.paramCase(entityMetadata.name)}' ` +
                `does not have field '${column.toLocaleLowerCase()}'`,
            source: {
                parameter: sourceParameter,
            },
        });
        return errors;
    }
    return errors;
}
exports.checkEntityFieldMetadata = checkEntityFieldMetadata;
//# sourceMappingURL=check-entity-field-metadata.js.map